TurboGears
==============

.. image:: https://travis-ci.org/TurboGears/tg2.png?branch=development
    :target: https://travis-ci.org/TurboGears/tg2

.. image:: https://coveralls.io/repos/TurboGears/tg2/badge.png?branch=development 
    :target: https://coveralls.io/r/TurboGears/tg2?branch=development

.. image:: https://pypip.in/v/TurboGears2/badge.png
   :target: https://pypi.python.org/pypi/TurboGears2

.. image:: https://pypip.in/d/TurboGears2/badge.png
   :target: https://pypi.python.org/pypi/TurboGears2


TurboGears is a hybrid web framework able to act both as a Full Stack
framework or as a Microframework. TurboGears helps you get going fast
and gets out of your way when you want it!

Support and Documentation
----------------------------

See the `TurboGears website <http://www.turbogears.org/>`_ to get
a quick overview of the framework or visit the 
`TurboGears Documentation <http://turbogears.readthedocs.org/>`_ 

License
-----------

TurboGears is licensed under an MIT-style license (see LICENSE.txt).
Other incorporated projects may be licensed under different licenses.
All licenses allow for non-commercial and commercial use.


